Trait nom::lib::std::prelude::v1::rust_2021::Sync1.0.0[−][src]

#[lang = "sync"]pub unsafe auto trait Sync { }

Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines it’s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include “immutable” types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

Types that are not Sync are those that have “interior mutability” in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Implementations on Foreign Types

impl Sync for Argument

impl Sync for FormatSpec

impl Sync for Alignment

impl Sync for Count

impl Sync for Once[src]

impl<T> !Sync for Receiver<T>[src]

impl<T> Sync for JoinHandle<T>[src]

impl<'_, T> Sync for MutexGuard<'_, T> where
    T: Sync + ?Sized, 
[src]

impl<T> Sync for SyncOnceCell<T> where
    T: Sync + Send, 
[src]

impl<'_, T> Sync for RwLockWriteGuard<'_, T> where
    T: Sync + ?Sized, 
[src]

impl !Sync for ArgsOs[src]

impl<'_, T> Sync for RwLockReadGuard<'_, T> where
    T: Sync + ?Sized, 
[src]

impl<T> Sync for Key<T>[src]

impl<T, F> Sync for SyncLazy<T, F> where
    F: Send,
    SyncOnceCell<T>: Sync, 
[src]

impl<T> !Sync for Sender<T>[src]

impl<'a> Sync for IoSliceMut<'a>[src]

impl<T> Sync for RwLock<T> where
    T: Send + Sync + ?Sized, 
[src]

impl<'a> Sync for IoSlice<'a>[src]

impl !Sync for Args[src]

impl<T> Sync for Mutex<T> where
    T: Send + ?Sized, 
[src]

impl<T> !Sync for UnsafeCell<T> where
    T: ?Sized, 
[src]

impl<Dyn> Sync for DynMetadata<Dyn> where
    Dyn: ?Sized, 
[src]

impl Sync for AtomicUsize[src]

impl Sync for AtomicU64[src]

impl Sync for AtomicIsize[src]

impl<T> !Sync for *const T where
    T: ?Sized, 
[src]

impl Sync for AtomicI32[src]

impl<T> !Sync for *mut T where
    T: ?Sized, 
[src]

impl Sync for AtomicU8[src]

impl Sync for AtomicBool[src]

impl Sync for AtomicI16[src]

impl Sync for AtomicI8[src]

impl Sync for Waker[src]

impl<T> !Sync for RefCell<T> where
    T: ?Sized, 
[src]

impl<T> Sync for AtomicPtr<T>[src]

impl Sync for AtomicI64[src]

impl Sync for AtomicU16[src]

impl<T> !Sync for Cell<T> where
    T: ?Sized, 
[src]

impl Sync for AtomicU32[src]

impl<T> !Sync for NonNull<T> where
    T: ?Sized, 
[src]

NonNull pointers are not Sync because the data they reference may be aliased.

impl<T> Sync for Weak<T> where
    T: Sync + Send + ?Sized, 
[src]

impl<T> !Sync for Rc<T> where
    T: ?Sized, 
[src]

impl<T> !Sync for Weak<T> where
    T: ?Sized, 
[src]

impl<T> Sync for Arc<T> where
    T: Sync + Send + ?Sized, 
[src]

impl Sync for isize

impl<T> Sync for [T] where
    T: Sync, 

impl Sync for [u8]

impl Sync for char

impl Sync for u128

impl Sync for u16

impl Sync for i128

impl Sync for i16

impl Sync for str

impl Sync for f64

impl Sync for u64

impl Sync for u8

impl Sync for i64

impl Sync for i8

impl<T, const N: usize> Sync for [T; N] where
    T: Sync, 

impl Sync for bool

impl Sync for f32

impl Sync for u32

impl Sync for usize

impl Sync for i32

Loading content...

Implementors

impl<'_> Sync for nom::lib::std::string::Drain<'_>1.6.0[src]

impl<'_, T> Sync for Cursor<'_, T> where
    T: Sync, 
[src]

impl<'_, T> Sync for CursorMut<'_, T> where
    T: Sync, 
[src]

impl<'_, T> Sync for nom::lib::std::collections::linked_list::Iter<'_, T> where
    T: Sync, 
[src]

impl<'_, T> Sync for nom::lib::std::collections::linked_list::IterMut<'_, T> where
    T: Sync, 
[src]

impl<'_, T> Sync for nom::lib::std::collections::vec_deque::Drain<'_, T> where
    T: Sync, 
1.6.0[src]

impl<'_, T> Sync for nom::lib::std::collections::vec_deque::IterMut<'_, T> where
    T: Sync, 
[src]

impl<'_, T> Sync for nom::lib::std::slice::Iter<'_, T> where
    T: Sync, 
[src]

impl<'_, T> Sync for nom::lib::std::slice::IterMut<'_, T> where
    T: Sync, 
[src]

impl<'_, T, A> Sync for nom::lib::std::vec::Drain<'_, T, A> where
    T: Sync,
    A: Sync + Allocator, 
1.6.0[src]

impl<T> Sync for LinkedList<T> where
    T: Sync, 
[src]

impl<T> Sync for Empty<T>1.42.0[src]

impl<T, A> Sync for nom::lib::std::vec::IntoIter<T, A> where
    T: Sync,
    A: Allocator, 
[src]

Loading content...

Auto implementors

impl Sync for CompareResult

impl Sync for Needed

impl Sync for ErrorKind

impl Sync for VerboseErrorKind

impl Sync for Ordering

impl Sync for TryReserveError

impl Sync for Infallible

impl Sync for nom::lib::std::fmt::Alignment

impl Sync for SearchStep

impl Sync for Endianness

impl Sync for AllocError

impl Sync for Global

impl Sync for Layout

impl Sync for LayoutError

impl Sync for System

impl Sync for DefaultHasher

impl Sync for RandomState

impl Sync for Error

impl Sync for SipHasher

impl Sync for RangeFull

impl Sync for NoneError

impl Sync for ParseBoolError

impl Sync for Utf8Error

impl Sync for FromUtf8Error

impl Sync for FromUtf16Error

impl Sync for String

impl<'a> !Sync for Arguments<'a>

impl<'a> !Sync for Formatter<'a>

impl<'a> Sync for CharSearcher<'a>

impl<'a> Sync for Bytes<'a>

impl<'a> Sync for CharIndices<'a>

impl<'a> Sync for Chars<'a>

impl<'a> Sync for EncodeUtf16<'a>

impl<'a> Sync for EscapeDebug<'a>

impl<'a> Sync for EscapeDefault<'a>

impl<'a> Sync for EscapeUnicode<'a>

impl<'a> Sync for Lines<'a>

impl<'a> Sync for LinesAny<'a>

impl<'a> Sync for SplitAsciiWhitespace<'a>

impl<'a> Sync for SplitWhitespace<'a>

impl<'a, 'b> !Sync for DebugList<'a, 'b>

impl<'a, 'b> !Sync for DebugMap<'a, 'b>

impl<'a, 'b> !Sync for DebugSet<'a, 'b>

impl<'a, 'b> !Sync for DebugStruct<'a, 'b>

impl<'a, 'b> !Sync for DebugTuple<'a, 'b>

impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>

impl<'a, 'b> Sync for StrSearcher<'a, 'b>

impl<'a, A> Sync for nom::lib::std::option::Iter<'a, A> where
    A: Sync, 

impl<'a, A> Sync for nom::lib::std::option::IterMut<'a, A> where
    A: Sync, 

impl<'a, B: ?Sized> Sync for Cow<'a, B> where
    B: Sync,
    <B as ToOwned>::Owned: Sync, 

impl<'a, F> Sync for CharPredicateSearcher<'a, F> where
    F: Sync, 

impl<'a, I, A> Sync for Splice<'a, I, A> where
    A: Sync,
    I: Sync,
    <I as Iterator>::Item: Sync, 

impl<'a, K> Sync for nom::lib::std::collections::hash_set::Drain<'a, K> where
    K: Sync, 

impl<'a, K> Sync for nom::lib::std::collections::hash_set::Iter<'a, K> where
    K: Sync, 

impl<'a, K, F> Sync for nom::lib::std::collections::hash_set::DrainFilter<'a, K, F> where
    F: Sync,
    K: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::Entry<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::Entry<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::Iter<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::IterMut<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::Keys<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::OccupiedEntry<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::OccupiedError<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::Range<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for RangeMut<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::VacantEntry<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::Values<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::btree_map::ValuesMut<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::Drain<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::Iter<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::IterMut<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::Keys<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::OccupiedEntry<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::OccupiedError<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::VacantEntry<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::Values<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V> Sync for nom::lib::std::collections::hash_map::ValuesMut<'a, K, V> where
    K: Sync,
    V: Sync, 

impl<'a, K, V, F> Sync for nom::lib::std::collections::btree_map::DrainFilter<'a, K, V, F> where
    F: Sync,
    K: Sync,
    V: Sync, 

impl<'a, K, V, F> Sync for nom::lib::std::collections::hash_map::DrainFilter<'a, K, V, F> where
    F: Sync,
    K: Sync,
    V: Sync, 

impl<'a, K, V, S> Sync for RawEntryMut<'a, K, V, S> where
    K: Sync,
    S: Sync,
    V: Sync, 

impl<'a, K, V, S> Sync for RawEntryBuilder<'a, K, V, S> where
    K: Sync,
    S: Sync,
    V: Sync, 

impl<'a, K, V, S> Sync for RawEntryBuilderMut<'a, K, V, S> where
    K: Sync,
    S: Sync,
    V: Sync, 

impl<'a, K, V, S> Sync for RawOccupiedEntryMut<'a, K, V, S> where
    K: Sync,
    V: Sync, 

impl<'a, K, V, S> Sync for RawVacantEntryMut<'a, K, V, S> where
    K: Sync,
    S: Sync,
    V: Sync, 

impl<'a, P> Sync for MatchIndices<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for Matches<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for RMatchIndices<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for RMatches<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for nom::lib::std::str::RSplit<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for nom::lib::std::str::RSplitN<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for RSplitTerminator<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for nom::lib::std::str::Split<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for SplitInclusive<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for nom::lib::std::str::SplitN<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, P> Sync for SplitTerminator<'a, P> where
    <P as Pattern<'a>>::Searcher: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::binary_heap::Drain<'a, T> where
    T: Sync, 

impl<'a, T> Sync for DrainSorted<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::binary_heap::Iter<'a, T> where
    T: Sync, 

impl<'a, T> Sync for PeekMut<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::btree_set::Difference<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::btree_set::Intersection<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::btree_set::Iter<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::btree_set::Range<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::btree_set::SymmetricDifference<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::btree_set::Union<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::collections::vec_deque::Iter<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::result::Iter<'a, T> where
    T: Sync, 

impl<'a, T> Sync for nom::lib::std::result::IterMut<'a, T> where
    T: Sync, 

impl<'a, T> Sync for Chunks<'a, T> where
    T: Sync, 

impl<'a, T> Sync for ChunksExact<'a, T> where
    T: Sync, 

impl<'a, T> Sync for ChunksExactMut<'a, T> where
    T: Sync, 

impl<'a, T> Sync for ChunksMut<'a, T> where
    T: Sync, 

impl<'a, T> Sync for RChunks<'a, T> where
    T: Sync, 

impl<'a, T> Sync for RChunksExact<'a, T> where
    T: Sync, 

impl<'a, T> Sync for RChunksExactMut<'a, T> where
    T: Sync, 

impl<'a, T> Sync for RChunksMut<'a, T> where
    T: Sync, 

impl<'a, T> Sync for Windows<'a, T> where
    T: Sync, 

impl<'a, T, F> !Sync for nom::lib::std::collections::linked_list::DrainFilter<'a, T, F>

impl<'a, T, F> Sync for nom::lib::std::collections::btree_set::DrainFilter<'a, T, F> where
    F: Sync,
    T: Sync, 

impl<'a, T, F, A> Sync for nom::lib::std::vec::DrainFilter<'a, T, F, A> where
    A: Sync,
    F: Sync,
    T: Sync, 

impl<'a, T, P> Sync for GroupBy<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for GroupByMut<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for nom::lib::std::slice::RSplit<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for RSplitMut<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for nom::lib::std::slice::RSplitN<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for RSplitNMut<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for nom::lib::std::slice::Split<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for SplitMut<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for nom::lib::std::slice::SplitN<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, P> Sync for SplitNMut<'a, T, P> where
    P: Sync,
    T: Sync, 

impl<'a, T, S> Sync for nom::lib::std::collections::hash_set::Difference<'a, T, S> where
    S: Sync,
    T: Sync, 

impl<'a, T, S> Sync for nom::lib::std::collections::hash_set::Intersection<'a, T, S> where
    S: Sync,
    T: Sync, 

impl<'a, T, S> Sync for nom::lib::std::collections::hash_set::SymmetricDifference<'a, T, S> where
    S: Sync,
    T: Sync, 

impl<'a, T, S> Sync for nom::lib::std::collections::hash_set::Union<'a, T, S> where
    S: Sync,
    T: Sync, 

impl<'a, T, const N: usize> !Sync for ArrayWindows<'a, T, N>

impl<'a, T, const N: usize> Sync for ArrayChunks<'a, T, N> where
    T: Sync, 

impl<'a, T, const N: usize> Sync for ArrayChunksMut<'a, T, N> where
    T: Sync, 

impl<A> Sync for Repeat<A> where
    A: Sync, 

impl<A> Sync for nom::lib::std::option::IntoIter<A> where
    A: Sync, 

impl<A, B> Sync for Chain<A, B> where
    A: Sync,
    B: Sync, 

impl<A, B> Sync for Zip<A, B> where
    A: Sync,
    B: Sync, 

impl<B, C> Sync for ControlFlow<B, C> where
    B: Sync,
    C: Sync, 

impl<E> Sync for Err<E> where
    E: Sync, 

impl<F> Sync for FromFn<F> where
    F: Sync, 

impl<F> Sync for OnceWith<F> where
    F: Sync, 

impl<F> Sync for RepeatWith<F> where
    F: Sync, 

impl<H> Sync for BuildHasherDefault<H> where
    H: Sync, 

impl<I> Sync for VerboseError<I> where
    I: Sync, 

impl<I> Sync for Cloned<I> where
    I: Sync, 

impl<I> Sync for Copied<I> where
    I: Sync, 

impl<I> Sync for Cycle<I> where
    I: Sync, 

impl<I> Sync for Enumerate<I> where
    I: Sync, 

impl<I> Sync for Flatten<I> where
    I: Sync,
    <<I as Iterator>::Item as IntoIterator>::IntoIter: Sync, 

impl<I> Sync for Fuse<I> where
    I: Sync, 

impl<I> Sync for Intersperse<I> where
    I: Sync,
    <I as Iterator>::Item: Sync, 

impl<I> Sync for Peekable<I> where
    I: Sync,
    <I as Iterator>::Item: Sync, 

impl<I> Sync for Skip<I> where
    I: Sync, 

impl<I> Sync for StepBy<I> where
    I: Sync, 

impl<I> Sync for Take<I> where
    I: Sync, 

impl<I, E, F> Sync for ParserIterator<I, E, F> where
    E: Sync,
    F: Sync,
    I: Sync, 

impl<I, F> Sync for FilterMap<I, F> where
    F: Sync,
    I: Sync, 

impl<I, F> Sync for Inspect<I, F> where
    F: Sync,
    I: Sync, 

impl<I, F> Sync for Map<I, F> where
    F: Sync,
    I: Sync, 

impl<I, G> Sync for IntersperseWith<I, G> where
    G: Sync,
    I: Sync,
    <I as Iterator>::Item: Sync, 

impl<I, P> Sync for Filter<I, P> where
    I: Sync,
    P: Sync, 

impl<I, P> Sync for MapWhile<I, P> where
    I: Sync,
    P: Sync, 

impl<I, P> Sync for SkipWhile<I, P> where
    I: Sync,
    P: Sync, 

impl<I, P> Sync for TakeWhile<I, P> where
    I: Sync,
    P: Sync, 

impl<I, St, F> Sync for Scan<I, St, F> where
    F: Sync,
    I: Sync,
    St: Sync, 

impl<I, U, F> Sync for FlatMap<I, U, F> where
    F: Sync,
    I: Sync,
    <U as IntoIterator>::IntoIter: Sync, 

impl<Idx> Sync for nom::lib::std::ops::Range<Idx> where
    Idx: Sync, 

impl<Idx> Sync for RangeFrom<Idx> where
    Idx: Sync, 

impl<Idx> Sync for RangeInclusive<Idx> where
    Idx: Sync, 

impl<Idx> Sync for RangeTo<Idx> where
    Idx: Sync, 

impl<Idx> Sync for RangeToInclusive<Idx> where
    Idx: Sync, 

impl<K> Sync for nom::lib::std::collections::hash_set::IntoIter<K> where
    K: Sync, 

impl<K, V> Sync for nom::lib::std::collections::btree_map::IntoIter<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V> Sync for nom::lib::std::collections::btree_map::IntoKeys<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V> Sync for nom::lib::std::collections::btree_map::IntoValues<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V> Sync for nom::lib::std::collections::hash_map::IntoIter<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V> Sync for nom::lib::std::collections::hash_map::IntoKeys<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V> Sync for nom::lib::std::collections::hash_map::IntoValues<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V> Sync for BTreeMap<K, V> where
    K: Sync,
    V: Sync, 

impl<K, V, S> Sync for HashMap<K, V, S> where
    K: Sync,
    S: Sync,
    V: Sync, 

impl<T> Sync for Bound<T> where
    T: Sync, 

impl<T> Sync for Option<T> where
    T: Sync, 

impl<T> Sync for Reverse<T> where
    T: Sync, 

impl<T> Sync for nom::lib::std::collections::binary_heap::IntoIter<T> where
    T: Sync, 

impl<T> Sync for IntoIterSorted<T> where
    T: Sync, 

impl<T> Sync for nom::lib::std::collections::btree_set::IntoIter<T> where
    T: Sync, 

impl<T> Sync for nom::lib::std::collections::linked_list::IntoIter<T> where
    T: Sync, 

impl<T> Sync for BTreeSet<T> where
    T: Sync, 

impl<T> Sync for BinaryHeap<T> where
    T: Sync, 

impl<T> Sync for VecDeque<T> where
    T: Sync, 

impl<T> Sync for nom::lib::std::collections::vec_deque::IntoIter<T> where
    T: Sync, 

impl<T> Sync for nom::lib::std::iter::Once<T> where
    T: Sync, 

impl<T> Sync for Rev<T> where
    T: Sync, 

impl<T> Sync for Discriminant<T>

impl<T> Sync for nom::lib::std::result::IntoIter<T> where
    T: Sync, 

impl<T> Sync for MaybeUninit<T> where
    T: Sync, 

impl<T, A> Sync for Vec<T, A> where
    A: Sync,
    T: Sync, 

impl<T, E> Sync for Result<T, E> where
    E: Sync,
    T: Sync, 

impl<T, F> Sync for Successors<T, F> where
    F: Sync,
    T: Sync, 

impl<T, S> Sync for HashSet<T, S> where
    S: Sync,
    T: Sync, 

impl<T: ?Sized> Sync for ManuallyDrop<T> where
    T: Sync, 

impl<T: ?Sized, A> Sync for Box<T, A> where
    A: Sync,
    T: Sync, 

impl<Y, R> Sync for GeneratorState<Y, R> where
    R: Sync,
    Y: Sync, 

Loading content...