Trait nom::lib::std::convert::AsMut 1.0.0[−][src]
Used to do a cheap mutable-to-mutable reference conversion.
This trait is similar to AsRef but used for converting between mutable
references. If you need to do a costly conversion it is better to
implement From with type &mut T or write a custom function.
Note: This trait must not fail. If the conversion can fail, use a
dedicated method which returns an Option<T> or a Result<T, E>.
Generic Implementations
AsMutauto-dereferences if the inner type is a mutable reference (e.g.:foo.as_mut()will work the same iffoohas type&mut Fooor&mut &mut Foo)
Examples
Using AsMut as trait bound for a generic function we can accept all mutable references
that can be converted to type &mut T. Because Box<T> implements AsMut<T> we can
write a function add_one that takes all arguments that can be converted to &mut u64.
Because Box<T> implements AsMut<T>, add_one accepts arguments of type
&mut Box<u64> as well:
fn add_one<T: AsMut<u64>>(num: &mut T) { *num.as_mut() += 1; } let mut boxed_num = Box::new(0); add_one(&mut boxed_num); assert_eq!(*boxed_num, 1);
Required methods
Loading content...Implementations on Foreign Types
impl AsMut<str> for str[src]
impl<'_, T, U> AsMut<U> for &'_ mut T where
T: AsMut<U> + ?Sized,
U: ?Sized, [src]
T: AsMut<U> + ?Sized,
U: ?Sized,
impl<T, const N: usize> AsMut<[T]> for [T; N][src]
impl<T> AsMut<[T]> for [T][src]
impl<O, T> AsMut<BitSlice<O, T>> for BitBox<O, T> where
O: BitOrder,
T: BitStore, [src]
O: BitOrder,
T: BitStore,
impl<O, T> AsMut<BitSlice<O, T>> for BitVec<O, T> where
O: BitOrder,
T: BitStore, [src]
O: BitOrder,
T: BitStore,
impl<O, V> AsMut<BitSlice<O, <V as BitView>::Store>> for BitArray<O, V> where
O: BitOrder,
V: BitView, [src]
O: BitOrder,
V: BitView,
impl<T> AsMut<T> for FmtUpperHex<T> where
T: UpperHex,
T: UpperHex,
impl<T> AsMut<T> for FmtLowerExp<T> where
T: LowerExp,
T: LowerExp,
impl<T> AsMut<T> for FmtBinary<T> where
T: Binary,
T: Binary,
impl<T> AsMut<T> for FmtDisplay<T> where
T: Display,
T: Display,
impl<T> AsMut<T> for FmtLowerHex<T> where
T: LowerHex,
T: LowerHex,
impl<T> AsMut<T> for FmtUpperExp<T> where
T: UpperExp,
T: UpperExp,
impl<T> AsMut<T> for FmtOctal<T> where
T: Octal,
T: Octal,
impl<T> AsMut<T> for FmtPointer<T> where
T: Pointer,
T: Pointer,
impl<A> AsMut<[<A as Array>::Item]> for ArrayVec<A> where
A: Array, [src]
Loading content...A: Array,
Implementors
impl AsMut<str> for String1.43.0[src]
impl<T, A> AsMut<[T]> for Vec<T, A> where
A: Allocator, 1.5.0[src]
A: Allocator,
impl<T, A> AsMut<Vec<T, A>> for Vec<T, A> where
A: Allocator, 1.5.0[src]
A: Allocator,
impl<T, A> AsMut<T> for Box<T, A> where
T: ?Sized,
A: Allocator, 1.5.0[src]
T: ?Sized,
A: Allocator,